import setuptools

with open("README.md", "r",encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name="util_belt", # Replace with your own username
    version="0.0.6",
    author="kellem negasi",
    author_email="kellemnegasi@gmail.com",
    description="A package of differnt utilities",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/kellemNegasi/util_belt",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)





def list_to_txt(list_object,file_dest='./list.txt'):
    with open(file_dest, 'w') as f:
        for item in list_object:
            f.write("%s\n" % item)
        print(f'written a list of length {len(list_object)} to {file_dest}')

def list_from_txt(file_src):
    list_ = []
    # open file and read the content in a list
    with open(file_src, 'r') as filehandle:
        list_ = [current_place.rstrip() for current_place in filehandle.readlines()]
    return list_